SystemOrganization addCategory: #'Rest-Tests'!
SystemOrganization addCategory: #'Rest-Tests-Server'!
SystemOrganization addCategory: #'Rest-Tests-Fixtures'!
SystemOrganization addCategory: #'Rest-Tests-Client-HTTP'!

!Dictionary methodsFor: '*rest-tests' stamp: 'mt 2/16/2009 10:28'!
keysAndValuesCollect: aBlock 
	| newDict |
	newDict := Dictionary new.
	self keysAndValuesDo: [:key :value | newDict add: (aBlock value: key value: value)].
	^ newDict! !

TestCase subclass: #RestHttpsSocketTestCase
	instanceVariableNames: 'site'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rest-Tests-Client-HTTP'!

!RestHttpsSocketTestCase class methodsFor: 'as yet unclassified' stamp: 'SR 2/19/2009 17:02'!
url
	^ 'https://www.google.com/' asUrl! !

!RestHttpsSocketTestCase methodsFor: 'as yet unclassified' stamp: 'SR 2/19/2009 17:01'!
testDefaultReturn

	self
		should: ((RestHttpsSocket    getDocumentFromUrl: self class url request: '') isKindOf: RestHttpsResponse);
		should: ((RestHttpsSocket    putDocumentFromUrl: self class url request: '' content: 'foo') isKindOf: RestHttpsResponse);
		should: ((RestHttpsSocket   postDocumentFromUrl: self class url request: '' content: 'bar') isKindOf: RestHttpsResponse);
		should: ((RestHttpsSocket deleteDocumentFromUrl: self class url request: '') isKindOf: RestHttpsResponse).! !

TestCase subclass: #RestTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rest-Tests-Server'!

RestTest subclass: #RestHttpServiceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rest-Tests-Server'!

!RestHttpServiceTest methodsFor: 'running' stamp: 'mt 2/17/2009 16:22'!
setUp
! !

!RestHttpServiceTest methodsFor: 'tests' stamp: 'mt 2/19/2009 16:10'!
testStartAndStop
	
	RestHttpService start.
	(Delay forMilliseconds: 100) wait.
	
	self
		should: (RestHttpService service isKindOf: RestHttpService);
		should: RestHttpService isRunning.
	
	RestHttpService stop.
	(Delay forMilliseconds: 100) wait.
	
	self
		should: (RestHttpService service isNil);
		shouldnt: RestHttpService isRunning.! !

RestTest subclass: #RestPerformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rest-Tests-Server'!

!RestPerformTest methodsFor: 'running' stamp: 'mt 2/16/2009 15:24'!
setUp
	super setUp.
	RestHttpService service 
		installHandler: RestPerformHttpHandler
		on: '/'! !

!RestPerformTest methodsFor: 'tests' stamp: 'mt 2/19/2009 17:24'!
testPort
	| response |
	response := self get: 'RestHttpService/port'.
	self should: response contents = RestHttpService port asString.! !

!RestTest class methodsFor: 'testing' stamp: 'cs 2/15/2009 14:14'!
isAbstract
	^ self name = 'RestTest'! !

!RestTest methodsFor: 'helping' stamp: 'mt 2/19/2009 10:11'!
createHttpResponseFrom: aString

	| response contentLength |
	response := HttpResponse fromString: '{"title" : "", "id" : "", "userStories" : {}, "tasks" : {}, "developers" : {}, "explanation" : "", "timeEstimated" : "", "timeActual" : "", "project" : ""}'.
	
"	aString linesDo: [:line|
		(line startsWith: 'HTTP')
			ifTrue: [response status: (HttpResponse statusSymbolFor: (line findTokens: Character space) second asNumber)].
		(line startsWith: 'Content-type')
			ifTrue: [response contentType: (line findTokens: $:) second withBlanksTrimmed].
		(line startsWith: 'Content-length')
			ifTrue: [contentLength := (line findTokens: $:) second asInteger]].
		
	response content: (aString copyFrom: (aString size - contentLength) to: aString size).
"
	^response! !

!RestTest methodsFor: 'helping' stamp: 'SR 2/19/2009 15:49'!
delete: aPath
	"Send an HTTP request with DELETE to localhost at the port of the (singleton) rest HTTP service."
	
	^ self createHttpResponseFrom: (RestHttpsSocket deleteDocumentFromUrl: (('http://localhost:{1}/{2}' format: {RestHttpService port. aPath}) asUrl) request: '')! !

!RestTest methodsFor: 'helping' stamp: 'SR 2/19/2009 15:47'!
get: aPath
	"Send an HTTP request with GET to localhost at the port of the (singleton) rest HTTP service."

	^ self createHttpResponseFrom: (RestHttpsSocket getDocumentFromUrl: (('http://localhost:{1}/{2}' format: {RestHttpService port. aPath}) asUrl) request: '')! !

!RestTest methodsFor: 'helping' stamp: 'mt 2/18/2009 15:09'!
jsonDataFrom: someFields
	"Create a string for all fields in the dictionary in JSON."
	
	| stream |
	stream := TextStream with: ''.
	(Dictionary newFrom: someFields) jsonWriteOn: stream.	
	^ stream contents! !

!RestTest methodsFor: 'helping' stamp: 'SR 2/19/2009 15:53'!
post: aPath content: aContent
	"Send an HTTP request with POST to localhost at the port of the (singleton) rest HTTP service. Append the given fields to the request body."
	
	^ self createHttpResponseFrom: (RestHttpsSocket postDocumentFromUrl: (('http://localhost:{1}/{2}' format: {RestHttpService port. aPath}) asUrl) request: '' content: aContent)! !

!RestTest methodsFor: 'helping' stamp: 'SR 2/19/2009 15:54'!
put: aPath content: aContent
	"Send an HTTP request with PUT to localhost at the port of the (singleton) rest HTTP service. Append the given fields to the request body."
		^ self createHttpResponseFrom: (RestHttpsSocket putDocumentFromUrl: (('http://localhost:{1}/{2}' format: {RestHttpService port. aPath}) asUrl) request: '' content: aContent)! !

!RestTest methodsFor: 'running' stamp: 'mt 2/16/2009 15:05'!
setUp
	RestHttpService start.
	"wait until the service is up"
	(Delay forMilliseconds: 100) wait.! !

!RestTest methodsFor: 'running' stamp: 'cs 2/15/2009 14:27'!
tearDown
	RestHttpService stop.! !
